@@ -3,11 +3,11 @@ from __future__ import annotations
 
 import asyncio
 import logging
-from typing import TYPE_CHECKING, Any, Coroutine, Generator, Union
+from typing import TYPE_CHECKING, Any, Callable, Coroutine, Generator
 
 from xknx.core import XknxConnectionState
 
-AsyncCallbackType = Union[Generator[Any, None, Any], Coroutine[Any, Any, None]]
+AsyncCallbackType = Callable[[], Coroutine[Any, Any, None]]
 
 if TYPE_CHECKING:
     from xknx import XKNX
@@ -21,23 +21,19 @@ class Task:
     def __init__(
         self,
         name: str,
-        task: AsyncCallbackType,
+        async_func: AsyncCallbackType,
         restart_after_reconnect: bool = False,
-        loop: asyncio.AbstractEventLoop | None = None,
     ) -> None:
         """Initialize Task class."""
         self.name = name
-        self.task = task
+        self.async_func = async_func
         self.restart_after_reconnect = restart_after_reconnect
         self._task: asyncio.Task[None] | None = None
-        self._loop = loop
 
-    def start(self) -> None:
+    def start(self) -> Task:
         """Start a task."""
-        if self._loop is not None:
-            self._task = self._loop.create_task(self.task, name=self.name)
-        else:
-            self._task = asyncio.create_task(self.task, name=self.name)
+        self._task = asyncio.create_task(self.async_func(), name=self.name)
+        return self
 
     def __await__(self) -> Generator[None, None, None]:
         """Wait for task to be finished."""
@@ -71,19 +67,13 @@ class TaskRegistry:
 
     def __init__(self, xknx: XKNX) -> None:
         """Initialize TaskRegistry class."""
-        self._main_loop: asyncio.AbstractEventLoop | None = None
-
         self.xknx = xknx
         self.tasks: list[Task] = []
 
-    async def register_loop(self) -> None:
-        """Register the main loop for thread safe interaction."""
-        self._main_loop = asyncio.get_running_loop()
-
     def register(
         self,
         name: str,
-        task: AsyncCallbackType,
+        async_func: AsyncCallbackType,
         track_task: bool = True,
         restart_after_reconnect: bool = False,
     ) -> Task:
@@ -92,9 +82,8 @@ class TaskRegistry:
 
         _task: Task = Task(
             name=name,
-            task=task,
+            async_func=async_func,
             restart_after_reconnect=restart_after_reconnect,
-            loop=self._main_loop,
         )
 
         if track_task:
