@@ -33,7 +33,7 @@ class NumericValue(Device):
         sync_state: bool | int | float | str = True,
         value_type: int | str | None = None,
         always_callback: bool = False,
-        device_updated_cb: DeviceCallbackType | None = None,
+        device_updated_cb: DeviceCallbackType[NumericValue] | None = None,
     ):
         """Initialize Sensor class."""
         super().__init__(xknx, name, device_updated_cb)
